Class: RuboCop::Cop::Betterment::AllowlistBlocklist

Inherits:
RuboCop::Cop
  • Object
show all
Defined in:
lib/rubocop/cop/betterment/allowlist_blocklist.rb

Constant Summary collapse

MSG =
<<-DOC.freeze
  Betterment has moved away from usages of whitelist & blacklist in favor of more inclusive terms.
  Replace any instances of these terms with more inclusive terms like allowlist, blocklist, denylist,
  ignorelist, warnlist, safelist, etc. We generally use allowlist and blocklist and prefer consistency where
  possible, but other terms may be more appropriate depending on your use case.

  This is part of a larger initiative to replace exclusionary / harmful language and anti-bias tools and products.
DOC

Instance Method Summary collapse

Instance Method Details

#on_class(node) ⇒ Object



15
16
17
# File 'lib/rubocop/cop/betterment/allowlist_blocklist.rb', line 15

def on_class(node)
  evaluate_node(node)
end